@@ -4,11 +4,12 @@ import socket
 import ssl
 
 
-class ssl_server:
+class SSLServer:
     def __init__(self, ip="0.0.0.0", port=4488):
         self.shutdown = False
         self.server = None
-        self.file_path = "".join((os.path.dirname(os.path.abspath(__file__)),os.sep))
+        self.file_path = "".join((os.path.dirname(os.path.abspath(__file__)),
+                                  os.sep))
         self.server = threading.Thread(target=self.start_server,
                                        kwargs={'ip': ip, 'port': port})
         self.server.setDaemon(True)
@@ -22,14 +23,15 @@ class ssl_server:
         ssl_socket.bind((ip, port))
         ssl_socket.listen(10)
         stream = None
-        server_cert = os.getenv('DEVO_SENDER_SERVER_CRT', ""
-                                .join((self.file_path,
-                                       "local_server_files",
-                                       os.sep, "server.crt")))
-        server_key = os.getenv('DEVO_SENDER_SERVER_KEY', ""
-                               .join((self.file_path,
-                                      "local_server_files",
-                                      os.sep, "server.key")))
+
+        server_cert = os.getenv('DEVO_SENDER_SERVER_CRT',
+                                "{!s}local_certs/keys/server/server_cert.pem"
+                                .format(self.file_path))
+
+        server_key = os.getenv('DEVO_SENDER_SERVER_KEY',
+                               "{!s}local_certs/keys/server/"
+                               "private/server_key.pem"
+                               .format(self.file_path))
         try:
             while not self.shutdown:
                 conn, addr = ssl_socket.accept()
@@ -63,7 +65,7 @@ class ssl_server:
         self.shutdown = True
 
 
-class tcp_server:
+class TCPServer:
     def __init__(self, ip="0.0.0.0", port=4489):
         self.shutdown = False
         self.server = None
